@@ -32,6 +32,8 @@
 #ifndef APDK_PRINTCONTEXT_H
 #define APDK_PRINTCONTEXT_H
 
+#include "printerfactory.h"
+
 APDK_BEGIN_NAMESPACE
 
 class PrintMode;
@@ -66,7 +68,7 @@ friend class HeaderAladdin;  // to use GUITopMargin
 friend class Header895;
 friend class Tester;
 friend class Header850;
-
+friend class LDLEncap;
 public:
     PrintContext(SystemServices *pSysServ,
                  unsigned int InputPixelsPerRow=0,
@@ -138,9 +140,8 @@ public:
         //  { return thePrinter->RealizeFont(eFont,bSize,eColor,
         //                                  bBold,bItalic,bUnderline); }
 #endif
-
-    // return the enum for the next model in DR (UNSUPPORTED when finished)
-    PRINTER_TYPE EnumDevices(unsigned int& currIdx) const;
+    // return the enum for the next model(UNSUPPORTED when finished)
+    PRINTER_TYPE EnumDevices(FAMILY_HANDLE& familyHandle) const;
 
     // PerformPrinterFunction (clean pen, etc.)
     // this is the preferred function to call
@@ -178,6 +179,15 @@ public:
 
     PHOTOTRAY_STATE PhotoTrayEngaged (BOOL bQueryPrinter);
 
+    //! Returns TRUE if a hagaki feed is present in printer.
+    BOOL HagakiFeedPresent(BOOL bQueryPrinter);
+
+#ifdef APDK_AUTODUPLEX
+    //!Returns TRUE if duplexer and hagaki feed (combined) unit is present in printer.
+
+    BOOL HagakiFeedDuplexerPresent(BOOL bQueryPrinter);
+#endif
+
     const char* PrinterModel();
     const char* PrintertypeToString(PRINTER_TYPE pt); // returns string for use in UI
 
@@ -227,11 +237,9 @@ public:
 #ifdef APDK_EXTENDED_MEDIASIZE
     BOOL  SetCustomSize (float width, float height);
 #endif
-    char* PrintModeID();
     unsigned int GetCurrentDyeCount();
     PEN_TYPE GetDefaultPenSet();
     PEN_TYPE GetInstalledPens();
-    const char* PentypeToString(PEN_TYPE pen);
 
 private:
 
