@@ -60,6 +60,7 @@ public:
     virtual DRIVER_ERROR CleanPen ();
     virtual DRIVER_ERROR Flush (int FlushSize);
     DRIVER_ERROR SetPens (PEN_TYPE eNewPen);
+	virtual DRIVER_ERROR CheckInkLevel();
 
     DISPLAY_STATUS ParseError (BYTE byStatusReg);
 
@@ -67,7 +68,7 @@ public:
 
 protected:
     DISPLAY_STATUS m_dsCurrentStatus;
-    void    InitPrintModes ();
+    virtual void InitPrintModes ();
 };
 
 class CrossBowGrayMode : public PrintMode
@@ -102,6 +103,54 @@ public:
     CrossBowPhotoMode ();
 };
 
+class SpearMDLNormalMode : public PrintMode
+{
+public:
+    SpearMDLNormalMode ();
+};
+
+
+class SpearMDLDraftMode : public PrintMode
+{
+public:
+    SpearMDLDraftMode ();
+
+};
+
+class SpearMDLPhotoMode : public PrintMode
+{
+public:
+    SpearMDLPhotoMode ();
+
+};
+
+#if defined (APDK_DJ3320)
+
+//! DJ3320Proxy
+/*!
+******************************************************************************/
+class DJ3320Proxy : public PrinterProxy
+{
+public:
+    DJ3320Proxy() : PrinterProxy(
+        "DJ3320",                   // family name
+        "deskjet 3320\0"                        // DeskJet 3320 - crossbow
+        "deskjet 3420\0"                        // DeskJet 3420 - crossbow
+		"deskjet 3325\0"                        // DeskJet 3325 - crossbow
+		"deskjet 3500\0"                        // DeskJet 3500 - stiletto/dagger
+#ifdef APDK_MLC_PRINTER
+		"psc 1100\0"                            // homer
+		"psc 1200\0"                            // homer
+		"officejet 4100\0"                      // Maui
+#endif
+    ) {m_iPrinterType = eDJ3320;}
+    inline Printer* CreatePrinter(SystemServices* pSS) const { return new DJ3320(pSS); }
+	inline PRINTER_TYPE GetPrinterType() const { return eDJ3320;}
+	inline unsigned int GetModelBit() const { return 0x100;}
+};
+
+#endif
+
 #define SWATH_HEIGHT    100     // Number of color nozzles to be used
 
 #ifdef  APDK_LDL_COMPRESS
@@ -231,10 +280,12 @@ private:
  */
 
     BYTE    m_cKtoCVertAlign;
+	BYTE    m_cPtoCVertAlign;
 
     DRIVER_ERROR    PrintSweep (UInt32 SweepSize,
                         BOOL ColorPresent,
                         BOOL BlackPresent,
+						BOOL PhotoPresent,
                         Int32 VerticalPosition,
                         Int32 LeftEdge,
                         Int32 RightEdge,
