@@ -42,24 +42,6 @@ extern uint32_t ulMapCONQUEST_ClMlxx[ 9 * 9 * 9 ];
 extern uint32_t ulMapVOLTAIRE_CCM_KCMY[ 9 * 9 * 9 ];
 extern uint32_t ulMapVOLTAIRE_CCM_K[ 9 * 9 * 9 ];
 
-//! DJ690Proxy
-/*!
-******************************************************************************/
-static class DJ6xxPhotoProxy : public PrinterProxy
-{
-public:
-    DJ6xxPhotoProxy() : PrinterProxy(
-        "DJ6xxPhoto",                   // family name
-        "DESKJET 61\0"                                      // DeskJet 61x Series
-        "DESKJET 64\0"                                      // DeskJet 64x Series
-        "DESKJET 69\0"                                      // DeskJet 69x Series
-#ifdef APDK_MLC_PRINTER
-#endif
-    ) {}
-    inline Printer* CreatePrinter(SystemServices* pSS) const { return new DJ6xxPhoto(pSS); }
-} DJ6xxPhotoProxy;
-
-
 //
 // ** DJ6xxPhoto:Printer CLASS **
 //
