@@ -73,6 +73,55 @@ enum STYLE_TYPE { UPRIGHT, ITALIC };
 
 enum WEIGHT_TYPE { NORMAL, BOLD };
 
+//
+// ** move these to intenal.h
+
+struct fOptSubSig
+{
+    float pi;
+    const float *means;
+};
+
+
+struct fOptClassSig
+{
+    int nsubclasses;
+    float variance;
+    float inv_variance;
+    float cnst;
+    struct fOptSubSig *OptSubSig;
+};
+
+
+struct fOptSigSet
+{
+    int nbands;
+    struct fOptClassSig *OptClassSig;
+};
+
+
+struct RESSYNSTRUCT
+{
+        int             Width;
+        int             ScaleFactorMultiplier;
+        int             ScaleFactorDivisor;
+//      int             CallerAlloc;         // Who does the memory alloc.
+        int             Remainder;           // For use in non integer scaling cases
+        int             Repeat;              // When to send an extra output raster
+        int             RastersinBuffer;     // # of currently buffered rasters
+        unsigned char*  Bufferpt[NUMBER_RASTERS];
+        int             BufferSize;
+        unsigned char*  Buffer;
+        struct fOptSigSet OS;
+        struct fOptSubSig rsOptSubSigPtr1[45];
+        struct fOptClassSig OCS;
+        float **joint_means;
+        float ***filter;
+        float filterPtr1[45];
+        float filterPtr2[45][9];
+        float joint_meansPtr1[45];
+
+};
 
 ///////////////////////////////////////////////////////////////////
 
@@ -247,7 +296,95 @@ protected:
     BOOL fractional;
 }; //Scaler
 
+#ifdef APDK_PSCRIPT
+class PScriptProxy;
+#endif
 
+#ifdef APDK_LJMONO
+class LJMonoProxy;
+#endif
+
+#ifdef APDK_LJCOLOR
+class LJColorProxy;
+#endif
+
+#if defined(APDK_PSP100) && defined (APDK_DJ9xxVIP)
+class PSP100Proxy;
+#endif
+
+#if defined(APDK_DJGENERICVIP) && defined (APDK_DJ9xxVIP)
+class DJGenericVIPProxy;
+#endif
+
+#ifdef APDK_DJ9xxVIP
+class DJ9xxVIPProxy;
+#endif
+
+#ifdef APDK_DJ9xx
+class DJ9xxProxy;
+#endif
+
+#if defined(APDK_DJ8xx)|| defined(APDK_DJ9xx)
+class DJ8xxProxy;
+#endif
+
+#if defined(APDK_DJ8xx)|| defined(APDK_DJ9xx)
+#ifdef APDK_DJ8x5
+class DJ8x5Proxy;
+#endif
+#endif
+
+#if defined(APDK_DJ890)
+class DJ890Proxy;
+#endif
+
+#if defined(APDK_DJ850)
+class DJ850Proxy;
+#endif
+
+#ifdef APDK_DJ6xxPhoto
+class DJ6xxPhotoProxy;
+#endif
+
+#ifdef APDK_DJ6xx
+class DJ660Proxy;
+#endif
+
+#ifdef APDK_DJ630
+class DJ630Proxy;
+#endif
+
+#ifdef APDK_DJ600
+class DJ600Proxy;
+#endif
+
+#ifdef APDK_DJ540
+class DJ540Proxy;
+#endif
+
+#ifdef APDK_DJ350
+class DJ350Proxy;
+#endif
+
+#if defined(APDK_DJ3600) && defined (APDK_DJ3320)
+class DJ3600Proxy;
+#endif
+
+#if defined (APDK_DJ3320)
+class DJ3320Proxy;
+#endif
+
+#ifdef APDK_APOLLO2560
+class Apollo2560Proxy;
+#endif
+
+#ifdef APDK_APOLLO21XX
+class Apollo21xxProxy;
+#endif
+
+#ifdef APDK_APOLLO2XXX
+class Apollo2xxxProxy;
+#endif
 //DeviceRegistry
 //! Isolates device dependencies
 /*!
@@ -268,13 +405,11 @@ public:
 
     // get model string from DevID string
     DRIVER_ERROR ParseDevIDString(const char* sDevID, char* strModel, int *pVIPVersion, char* strPens);
-
-    // return the string representing the next model (NULL when finished)
-    PRINTER_TYPE EnumDevices(unsigned int& currIdx) const;
-
     // set "device" to index of entry
     virtual DRIVER_ERROR SelectDevice(char* model, int* pVIPVersion, char* pens, SystemServices* pSS);
 
+    virtual DRIVER_ERROR SelectDevice(const char* sDevID, SystemServices* pSS);
+
     virtual DRIVER_ERROR SelectDevice(const PRINTER_TYPE Model);
 
     virtual DRIVER_ERROR GetPrinterModel(char* strModel, int* pVIPVersion, char* strPens, SystemServices* pSS);
@@ -287,6 +422,96 @@ public:
 
     int device;                         // ordinal of device from list (or UNSUPPORTED=-1)
 
+#ifdef APDK_PSCRIPT
+    static PScriptProxy s_PScriptProxy;
+#endif
+
+#ifdef APDK_LJMONO
+    static LJMonoProxy s_LJMonoProxy;
+#endif
+
+#ifdef APDK_LJCOLOR
+    static LJColorProxy s_LJColorProxy;
+#endif
+
+#if defined(APDK_PSP100) && defined (APDK_DJ9xxVIP)
+    static PSP100Proxy s_PSP100Proxy;
+#endif
+
+#if defined(APDK_DJGENERICVIP) && defined (APDK_DJ9xxVIP)
+    static DJGenericVIPProxy s_DJGenericVIPProxy;
+#endif
+
+#ifdef APDK_DJ9xxVIP
+    static DJ9xxVIPProxy s_DJ9xxVIPProxy;
+#endif
+
+#ifdef APDK_DJ9xx
+    static DJ9xxProxy s_DJ9xxProxy;
+#endif
+
+#if defined(APDK_DJ8xx)|| defined(APDK_DJ9xx)
+    static DJ8xxProxy s_DJ8xxProxy;
+#endif
+
+#if defined(APDK_DJ8xx)|| defined(APDK_DJ9xx)
+#ifdef APDK_DJ8x5
+    static DJ8x5Proxy s_DJ8x5Proxy;
+#endif
+#endif
+
+#if defined(APDK_DJ890)
+    static DJ890Proxy s_DJ890Proxy;
+#endif
+
+#if defined(APDK_DJ850)
+    static DJ850Proxy s_DJ850Proxy;
+#endif
+
+#ifdef APDK_DJ6xxPhoto
+    static DJ6xxPhotoProxy s_DJ6xxPhotoProxy;
+#endif
+
+#ifdef APDK_DJ6xx
+    static DJ660Proxy s_DJ660Proxy;
+#endif
+
+#ifdef APDK_DJ630
+    static DJ630Proxy s_DJ630Proxy;
+#endif
+
+#ifdef APDK_DJ600
+    static DJ600Proxy s_DJ600Proxy;
+#endif
+
+#ifdef APDK_DJ540
+    static DJ540Proxy s_DJ540Proxy;
+#endif
+
+#ifdef APDK_DJ350
+    static DJ350Proxy s_DJ350Proxy;
+#endif
+
+#if defined(APDK_DJ3600) && defined (APDK_DJ3320)
+    static DJ3600Proxy s_DJ3600Proxy;
+#endif
+
+#if defined (APDK_DJ3320)
+    static DJ3320Proxy s_DJ3320Proxy;
+#endif
+
+#ifdef APDK_APOLLO2560
+    static Apollo2560Proxy s_Apollo2560Proxy;
+#endif
+
+#ifdef APDK_APOLLO21XX
+    static Apollo21xxProxy s_Apollo21xxProxy;
+#endif
+
+#ifdef APDK_APOLLO2XXX
+    static Apollo2xxxProxy s_Apollo2xxxProxy;
+#endif
+
 }; //DeviceRegistry
 
 
