@@ -35,22 +35,124 @@
 #include "header.h"
 #include "printerfactory.h"
 
+#include "printer.h"
+#include "apollo2xxx.h"
+#include "apollo21xx.h"
+#include "apollo2560.h"
+#include "apollo2xxx.h"
+#include "dj3320.h"
+#include "dj3600.h"
+#include "dj400.h"
+#include "dj6xx.h"
+#include "dj600.h"
+#include "dj630.h"
+#include "dj660.h"
+#include "dj690.h"
+#include "dj350.h"
+#include "dj540.h"
+#include "dj8xx.h"
+#include "dj850.h"
+#include "dj8x5.h"
+#include "dj890.h"
+#include "dj9xx.h"
+#include "dj9xxvip.h"
+#include "djgenericvip.h"
+#include "ljmono.h"
+#include "ljcolor.h"
+#include "psp100.h"
+#include "pscript.h"
+
 APDK_BEGIN_NAMESPACE
 
-extern PRINTER_TYPE DevIDMap[MAX_ID_STRING];
-extern char *ModelString[MAX_ID_STRING];
-extern PRINTER_TYPE BuiltIn[];
-extern unsigned int BuiltInSize;
+#ifdef APDK_PSCRIPT
+PScriptProxy DeviceRegistry::s_PScriptProxy;
+#endif
 
+#ifdef APDK_LJMONO
+LJMonoProxy DeviceRegistry::s_LJMonoProxy;
+#endif
 
-PRINTER_TYPE DevIDtoPT(unsigned int StringIndex)
-{
-    if (StringIndex >= MAX_ID_STRING)
-        return UNSUPPORTED;
+#ifdef APDK_LJCOLOR
+LJColorProxy DeviceRegistry::s_LJColorProxy;
+#endif
 
-    return DevIDMap[StringIndex];
-}
+#if defined(APDK_PSP100) && defined (APDK_DJ9xxVIP)
+PSP100Proxy DeviceRegistry::s_PSP100Proxy;
+#endif
 
+#if defined(APDK_DJGENERICVIP) && defined (APDK_DJ9xxVIP)
+DJGenericVIPProxy DeviceRegistry::s_DJGenericVIPProxy;
+#endif
+
+#ifdef APDK_DJ9xx
+DJ9xxProxy DeviceRegistry::s_DJ9xxProxy;
+#endif
+
+#ifdef APDK_DJ9xxVIP
+DJ9xxVIPProxy DeviceRegistry::s_DJ9xxVIPProxy;
+#endif
+
+#if defined(APDK_DJ8xx)|| defined(APDK_DJ9xx)
+DJ8xxProxy DeviceRegistry::s_DJ8xxProxy;
+#endif
+
+#if defined(APDK_DJ8xx)|| defined(APDK_DJ9xx)
+#ifdef APDK_DJ8x5
+DJ8x5Proxy DeviceRegistry::s_DJ8x5Proxy;
+#endif
+#endif
+
+#if defined(APDK_DJ890)
+DJ890Proxy DeviceRegistry::s_DJ890Proxy;
+#endif
+
+#if defined(APDK_DJ850)
+DJ850Proxy DeviceRegistry::s_DJ850Proxy;
+#endif
+
+#ifdef APDK_DJ6xxPhoto
+DJ6xxPhotoProxy DeviceRegistry::s_DJ6xxPhotoProxy;
+#endif
+
+#ifdef APDK_DJ6xx
+DJ660Proxy DeviceRegistry::s_DJ660Proxy;
+#endif
+
+#ifdef APDK_DJ630
+DJ630Proxy DeviceRegistry::s_DJ630Proxy;
+#endif
+
+#ifdef APDK_DJ600
+DJ600Proxy DeviceRegistry::s_DJ600Proxy;
+#endif
+
+#ifdef APDK_DJ540
+DJ540Proxy DeviceRegistry::s_DJ540Proxy;
+#endif
+
+#ifdef APDK_DJ350
+DJ350Proxy DeviceRegistry::s_DJ350Proxy;
+#endif
+
+#if defined(APDK_DJ3600) && defined (APDK_DJ3320)
+DJ3600Proxy DeviceRegistry::s_DJ3600Proxy;
+#endif
+
+#if defined (APDK_DJ3320)
+DJ3320Proxy DeviceRegistry::s_DJ3320Proxy;
+#endif
+
+#ifdef APDK_APOLLO2560
+Apollo2560Proxy DeviceRegistry::s_Apollo2560Proxy;
+#endif
+
+#ifdef APDK_APOLLO21XX
+Apollo21xxProxy DeviceRegistry::s_Apollo21xxProxy;
+#endif
+
+#ifdef APDK_APOLLO2XXX
+Apollo2xxxProxy DeviceRegistry::s_Apollo2xxxProxy;
+#endif
 
 DeviceRegistry::DeviceRegistry()
     : device(UNSUPPORTED)
@@ -70,7 +172,7 @@ DRIVER_ERROR DeviceRegistry::SelectDevice(const PRINTER_TYPE Model)
         return UNSUPPORTED_PRINTER;
     device = Model;
 
- return NO_ERROR;
+	return NO_ERROR;
 }
 
 
@@ -86,8 +188,7 @@ DRIVER_ERROR DeviceRegistry::SelectDevice(char* model, int *pVIPVersion, char* p
     printf("DR::SelectDevice: pens= '%s'\n",pens);
 #endif
 
-    unsigned int i=0; // counter for model type
-    unsigned int j=0; // counter for string parsing
+	int j = 0;
     char pen1 = '\0';   // black/color(for CCM)/photo(for 690) pen
     char pen2 = '\0';   // color/non-existent(for CCM) pen
 
@@ -95,18 +196,12 @@ DRIVER_ERROR DeviceRegistry::SelectDevice(char* model, int *pVIPVersion, char* p
 
     DRIVER_ERROR err = NO_ERROR;
 
-    while (!match && (i < MAX_ID_STRING))
+    FAMILY_HANDLE familyHandle = pPFI->FindDevIdMatch(model);
+    if (familyHandle != NULL)
     {
-        if (! strncmp(model,ModelString[i],strlen(ModelString[i])) )
-        {
-            match=TRUE;
-            device = DevIDtoPT(i);
-        }
-        else
-        {
-            i++;
-        }
-    }
+		device = pPFI->GetFamilyType(familyHandle);
+		match = TRUE;
+	}
 
     if (!match) // see if printer supports VIP, if so set compatible device
     {
@@ -138,7 +233,14 @@ DRIVER_ERROR DeviceRegistry::SelectDevice(char* model, int *pVIPVersion, char* p
             match = TRUE;
         }
 		char	*cmdStr = strstr ((const char *) DevIDBuffer+2, "CMD:");
-		if (!match && (strstr ((const char *) cmdStr+4, "POSTSCRIPT")))
+		if (!cmdStr)
+		{
+			cmdStr = strstr ((const char *) DevIDBuffer+2, "COMMAND SET:");
+		}
+		if (!match && cmdStr && (strstr ((const char *) cmdStr+4, "POSTSCRIPT") || 
+			                     strstr ((const char *) cmdStr+4, "PostScript") || 
+					             strstr ((const char *) cmdStr+4, "Postscript") || 
+					             strstr ((const char *) cmdStr+4, "postscript") ))
 		{
 			device = ePScript;
 			match = TRUE;
@@ -296,10 +398,10 @@ DRIVER_ERROR DeviceRegistry::SelectDevice(char* model, int *pVIPVersion, char* p
 
     // Early Venice printer do not yet have full bi-di so check
     // the model to avoid a communication problem.
-    if ( ( (strncmp(model,ModelString[DEVID_MODEL_81X],strlen(ModelString[DEVID_MODEL_81X])) == 0)
-        || (strncmp(model,ModelString[DEVID_MODEL_83X],strlen(ModelString[DEVID_MODEL_83X])) == 0)
-        || (strncmp(model,ModelString[DEVID_MODEL_88X],strlen(ModelString[DEVID_MODEL_88X])) == 0)
-        || (strncmp(model,ModelString[DEVID_MODEL_895],strlen(ModelString[DEVID_MODEL_895])) == 0)
+    if ( ( (strncmp(model,"DESKJET 81",10) == 0)
+        || (strncmp(model,"DESKJET 83",10) == 0)
+        || (strncmp(model,"DESKJET 88",10) == 0)
+        || (strncmp(model,"DESKJET 895",11) == 0)
          )
         && (pSS->IOMode.bUSB)
        )
@@ -309,8 +411,8 @@ DRIVER_ERROR DeviceRegistry::SelectDevice(char* model, int *pVIPVersion, char* p
         pSS->IOMode.bDevID = FALSE;
     }
 
-    if ( ( (strncmp(model,ModelString[DEVID_MODEL_63X],strlen(ModelString[DEVID_MODEL_63X])) == 0)
-        || (strncmp(model,ModelString[DEVID_MODEL_64X],strlen(ModelString[DEVID_MODEL_64X])) == 0)
+    if ( ( (strncmp(model,"DESKJET 63",10) == 0)
+        || (strncmp(model,"DESKJET 64",10) == 0)
          )
         && (pSS->IOMode.bUSB)
        )
@@ -323,6 +425,20 @@ DRIVER_ERROR DeviceRegistry::SelectDevice(char* model, int *pVIPVersion, char* p
     else return NO_ERROR;
 } //SelectDevice
 
+DRIVER_ERROR DeviceRegistry::SelectDevice(const char* sDevID, SystemServices* pSS)
+{
+    char strModel[DevIDBuffSize]; // to contain the MODEL (MDL) from the DevID
+    char strPens[64];   // to contain the VSTATUS penID from the DevID
+    int  VIPVersion;    // VIP version from the DevID
+
+	DRIVER_ERROR err = ParseDevIDString(sDevID, strModel, &VIPVersion, strPens);
+	if (err != NO_ERROR)
+	{
+		return UNSUPPORTED_PRINTER;
+	}
+
+	return SelectDevice(strModel, &VIPVersion, strPens, pSS);
+}
 
 DRIVER_ERROR DeviceRegistry::InstantiatePrinter(Printer*& p, SystemServices* pSS)
 // Instantiate a printer object and return a pointer p based on the previously
@@ -468,7 +584,7 @@ DRIVER_ERROR DeviceRegistry::ParseDevIDString(const char* sDevID, char* strModel
         HEXTOINT (*(pStr+3), &iVersion);
         iVersion = iVersion << 4;
         HEXTOINT (*(pStr+4), &iVersion);
-        if (iVersion < 2)
+        if (iVersion <= 2)
         {
             pStr += 19;     // get to the number of pens field
         }
@@ -504,21 +620,5 @@ DRIVER_ERROR DeviceRegistry::ParseDevIDString(const char* sDevID, char* strModel
     return NO_ERROR;
 } //ParseDevIDString
 
-
-PRINTER_TYPE DeviceRegistry::EnumDevices(unsigned int& currIdx) const
-// Returns next model; UNSUPPORTED when finished
-{
-    PRINTER_TYPE pt;
-
-    if (currIdx >=  BuiltInSize)
-        return UNSUPPORTED;
-
-    pt = BuiltIn[currIdx];
-
-    currIdx++;
-
-    return pt;
-} //EnumDevices
-
 APDK_END_NAMESPACE
 
