@@ -28,14 +28,9 @@
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 \*****************************************************************************/
 
-
-#ifdef APDK_PROTO
-#include "..\common\header.h"
-#include "..\common\scaler_open.h"
-#else
 #include "header.h"
 #include "scaler_open.h"
-#endif
+
 
 APDK_BEGIN_NAMESPACE
 
