@@ -29,6 +29,8 @@
 \*****************************************************************************/
 
 #include "header.h"
+#include "printerfactory.h"
+
 APDK_BEGIN_NAMESPACE
 extern BOOL ProprietaryImaging();
 extern BOOL ProprietaryScaling();
@@ -42,13 +44,9 @@ extern char DeveloperString[32];
 @{
 */
 
-const char VersionStringID[21] = "03.06.00A_03-31-2003";   //!< Version information
-
-char result[300];
-
-extern unsigned int modelbits();
-extern char* modelresult();
+const char VersionStringID[21] = "03.07.00A_08-31-2003";   //!< Version information
 
+char result[500];
 
 void HP_strcat(char* str1, const char* str2)
 {
@@ -119,7 +117,7 @@ char* Version(BOOL bCompressed)
         bits = bits | 0x00800000;
 #endif
 
-    bits = bits | modelbits();
+    bits = bits | pPFI->GetModelBits();
 
   // room left for 23 more here
         sprintf(result,"%0x", bits);
@@ -178,8 +176,9 @@ char* Version(BOOL bCompressed)
         HP_strcat(result,"memory ");
 #endif
 
-
-        HP_strcat(result, modelresult());
+		char modelstring[300];
+		pPFI->GetModelString(modelstring);
+        HP_strcat(result, modelstring);
 
     }
 
